package de.andrena.objektforum.timeconcepts;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

public class FormattingAndParsing {

    @Nested
    class formatting {

        @Test
        void formattingInstant_requiresZoneId() {
            DateTimeFormatter formatter = DateTimeFormatter
                .ofPattern("dd.MM.yyyy HH:mm")
                .withZone(ZoneId.of("Asia/Singapore"));

            Instant now = Instant.now();
            System.out.println(formatter.format(now));
        }

        @Test
        void formattingLocalDateTime_noNeedForZoneId() {
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("dd.MM.yyyy HH:mm");

            LocalDateTime localDateTime = LocalDateTime.of(2020, 5, 12, 16, 30);
            System.out.println(formatter.format(localDateTime));
        }

        @Test
        void formattingZonedDateTime() {
            DateTimeFormatter formatterWithoutZoneId = DateTimeFormatter
                .ofPattern("dd.MM.yyyy HH:mm");
            DateTimeFormatter formatterForSingaporeTime = DateTimeFormatter
                .ofPattern("dd.MM.yyyy HH:mm")
                .withZone(ZoneId.of("Asia/Singapore"));

            ZonedDateTime zonedDateTime = LocalDateTime.of(2020, 5, 12, 16, 30).atZone(ZoneId.of("Europe/Berlin"));
            System.out.println(formatterWithoutZoneId.format(zonedDateTime));
            System.out.println(formatterForSingaporeTime.format(zonedDateTime));
        }
    }

    @Test
    void parsing() {
        DateTimeFormatter formatter = DateTimeFormatter
            .ofPattern("dd.MM.yyyy HH:mm")
            .withZone(ZoneId.of("Asia/Singapore"));

        Instant parsed = Instant.from(formatter.parse("01.01.2020 00:00"));
        System.out.println(parsed);
    }
}
