package de.andrena.objektforum.timeconcepts;

import static de.andrena.objektforum.timeconcepts.Util.formatInstant;
import static de.andrena.objektforum.timeconcepts.Util.formatLocalDateTime;
import static java.time.Month.JUNE;
import static java.time.temporal.ChronoUnit.DAYS;
import static java.time.temporal.ChronoUnit.MONTHS;
import static org.assertj.core.api.Assertions.assertThatThrownBy;

import java.time.Instant;
import java.time.LocalDateTime;

import org.junit.jupiter.api.Test;

public class InstantAndLocalDateTime {

    @Test
    void localDateTime() {
        LocalDateTime dateTime = LocalDateTime.of(2020, JUNE, 15, 18, 31, 42);

        System.out.println(dateTime);
        System.out.println(dateTime.plus(31, DAYS));
        System.out.println(dateTime.plus(1, MONTHS));
        System.out.println();
        System.out.println(formatLocalDateTime(dateTime));
    }

    @Test
    void instant() {
        Instant now = Instant.now();

        System.out.println(now); // ISO String in UTC
        System.out.println(now.plus(31, DAYS));
        assertThatThrownBy(() -> now.plus(1, MONTHS)).hasMessageContaining("Unsupported unit: Months");
        System.out.println();
        System.out.println(formatInstant(now));
    }

    @Test
    void instantAndEpochMilli() {
        long currentTimeMillis = System.currentTimeMillis();
        Instant instantFromMillis = Instant.ofEpochMilli(currentTimeMillis);
        Instant instantNow = Instant.now();

        System.out.println(currentTimeMillis);
        System.out.println(instantFromMillis.toEpochMilli());
        System.out.println(instantNow.toEpochMilli());
    }

}
